<template>
	<van-uploader
		:after-read="afterRead"
		:before-delete="beforeDelete"
		v-model="getFileList"
		accept="image/png, image/jpeg"
		:max-size="10 * 1024 * 1024"
		@oversize="oversize"
		:disabled="disabled"
		:readonly="readonly"
	/>
</template>

<script>
import { uploadAlarmFile, deleteAlarmFile } from "@/assets/js/api"
export default {
	name: "v-upload",
	props: {
		value: {
			type: String,
			default: "",
		},
		disabled: {
			type: Boolean,
			default: false,
		},
		readonly: {
			type: Boolean,
			default: false,
		},
		afterOrBefore: {
			type: String,
			default: "before",
		},
		stationId: {
			type: Number,
			default: 0,
		},
	},
	data() {
		return {
			fileList: this.value,
		}
	},
	model: {
		prop: "value",
		event: "valChange",
	},
	watch: {
		value(newValue) {
			this.fileList = newValue
		},
		fileList(newValue) {
			this.$emit("valChange", newValue)
		},
	},
	computed: {
		getFileList: {
			get() {
				if (this.fileList) {
					return this.fileList.split(",").map((item) => {
						console.log(this.$units.getStationSrc(item))
						return {
							url: this.$units.getStationSrc(item),
							url1: item,
						}
					})
				}
				return []
			},
			set(newValue) {
				var fileList = []
				newValue.forEach((item) => {
					if (item.url1) {
						fileList.push(item.url1)
					}
				})
				this.fileList = fileList.join(",")
			},
		},
	},
	methods: {
		// 上传图片
		afterRead(file) {
			var formData = new FormData()
			let json = JSON.stringify({
				afterOrBefore: this.afterOrBefore,
				stationId: this.stationId,
			})
			formData.append("file", file.file)
			formData.append("json", json)
			//上传图片接口
			uploadAlarmFile(formData).then((res) => {
				let resData = JSON.parse(res.data.result)
				if (resData.code == 1) {
					if (this.fileList) {
						var arr = this.fileList.split(",")
						arr.push(resData.data[0])
						this.fileList = arr.join(",")
						return false
					}
					this.fileList = resData.data[0]
				}
			})
		},
		// 删除图片
		beforeDelete(file, detail) {
			let fileName = file.url1.split("/")[file.url1.split("/").length - 1]
			let postData = {
				filePath: this.stationId,
				fileName: fileName,
				fileType: this.afterOrBefore,
			}
			deleteAlarmFile(postData)
				.then((res) => {
					let resData = JSON.parse(res.data.result)
					if (resData.code == 1) {
						var arr = this.fileList.split(",")
						arr.splice(detail.index, 1)
						this.fileList = arr.join(",")
					} else {
						this.$toast(resData.msg)
						return false
					}
				})
				.catch((err) => {
					this.$toast("删除文件失败!")
					console.log(err)
					return false
				})
		},
		// 文件过大
		oversize(e) {
			this.$toast.fail("图片过大！")
		},
	},
}
</script>

<style scoped>
</style>